<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>SeekOption</name>
    <message>
        <location filename="../seekoption.cpp" line="38"/>
        <source>Seek to position in the current track</source>
        <translation type="unfinished">Zu Position im derzeitigen Stück spulen</translation>
    </message>
    <message>
        <location filename="../seekoption.cpp" line="39"/>
        <source>Seek forward</source>
        <translation>Vorwärts spulen</translation>
    </message>
    <message>
        <location filename="../seekoption.cpp" line="40"/>
        <source>Seek backwards</source>
        <translation>Rückwärts spulen</translation>
    </message>
</context>
</TS>
